@@ -7,6 +7,7 @@
 use super::api::ZomeCall;
 use super::interface::SignalBroadcaster;
 use super::manager::ManagedTaskAdd;
+use super::space::Space;
 use crate::conductor::api::CellConductorApi;
 use crate::conductor::api::CellConductorApiT;
 use crate::conductor::cell::error::CellResult;
@@ -20,11 +21,7 @@ use crate::core::ribosome::real_ribosome::RealRibosome;
 use crate::core::ribosome::ZomeCallInvocation;
 use crate::core::workflow::call_zome_workflow;
 use crate::core::workflow::countersigning_workflow::countersigning_success;
-use crate::core::workflow::countersigning_workflow::incoming_countersigning;
-use crate::core::workflow::countersigning_workflow::CountersigningWorkspace;
 use crate::core::workflow::genesis_workflow::genesis_workflow;
-use crate::core::workflow::incoming_dht_ops_workflow::incoming_dht_ops_workflow;
-use crate::core::workflow::incoming_dht_ops_workflow::IncomingOpHashes;
 use crate::core::workflow::initialize_zomes_workflow;
 use crate::core::workflow::CallZomeWorkflowArgs;
 use crate::core::workflow::GenesisWorkflowArgs;
@@ -38,20 +35,18 @@ use hash_type::AnyDht;
 use holo_hash::*;
 use holochain_cascade::authority;
 use holochain_cascade::Cascade;
-use holochain_p2p::dht_arc::ArcInterval;
-use holochain_p2p::dht_arc::DhtArcSet;
 use holochain_serialized_bytes::SerializedBytes;
 use holochain_sqlite::prelude::*;
 use holochain_state::host_fn_workspace::HostFnWorkspace;
+use holochain_state::host_fn_workspace::SourceChainWorkspace;
 use holochain_state::prelude::*;
 use holochain_state::schedule::live_scheduled_fns;
 use holochain_types::prelude::*;
-use kitsune_p2p::event::TimeWindow;
-use observability::OpenSpanExt;
 use rusqlite::OptionalExtension;
 use rusqlite::Transaction;
 use std::hash::Hash;
 use std::hash::Hasher;
+use std::sync::Arc;
 use tokio::sync;
 use tracing::*;
 use tracing_futures::Instrument;
@@ -98,22 +93,18 @@ impl PartialEq for Cell {
 /// The [Conductor] manages a collection of Cells, and will call functions
 /// on the Cell when a Conductor API method is called (either a
 /// [CellConductorApi] or an [AppInterfaceApi])
-pub struct Cell<Api = CellConductorApi, P2pCell = holochain_p2p::HolochainP2pCell>
+pub struct Cell<Api = CellConductorApi, P2pCell = holochain_p2p::HolochainP2pDna>
 where
     Api: CellConductorApiT,
-    P2pCell: holochain_p2p::HolochainP2pCellT,
+    P2pCell: holochain_p2p::HolochainP2pDnaT,
 {
     id: CellId,
     conductor_api: Api,
-    env: EnvWrite,
-    cache: EnvWrite,
+    conductor_handle: ConductorHandle,
+    space: Space,
     holochain_p2p_cell: P2pCell,
     queue_triggers: QueueTriggers,
     init_mutex: tokio::sync::Mutex<()>,
-    /// Countersigning workspace that is shared across this cell.
-    countersigning_workspace: CountersigningWorkspace,
-    /// Incoming op hashes that are queued for processing.
-    incoming_op_hashes: IncomingOpHashes,
 }
 
 impl Cell {
@@ -128,9 +119,8 @@ impl Cell {
     pub async fn create(
         id: CellId,
         conductor_handle: ConductorHandle,
-        env: EnvWrite,
-        cache: EnvWrite,
-        holochain_p2p_cell: holochain_p2p::HolochainP2pCell,
+        space: Space,
+        holochain_p2p_cell: holochain_p2p::HolochainP2pDna,
         managed_task_add_sender: sync::mpsc::Sender<ManagedTaskAdd>,
         managed_task_stop_broadcaster: sync::broadcast::Sender<()>,
     ) -> CellResult<(Self, InitialQueueTriggers)> {
@@ -139,23 +129,19 @@ impl Cell {
         // check if genesis has been run
         let has_genesis = {
             // check if genesis ran.
-            GenesisWorkspace::new(env.clone())?
+            GenesisWorkspace::new(space.authored_env.clone(), space.dht_env.clone())?
                 .has_genesis(id.agent_pubkey().clone())
                 .await?
         };
 
         if has_genesis {
-            let incoming_op_hashes = IncomingOpHashes::default();
-            let countersigning_workspace = CountersigningWorkspace::new();
             let (queue_triggers, initial_queue_triggers) = spawn_queue_consumer_tasks(
-                env.clone(),
-                cache.clone(),
+                id.clone(),
                 holochain_p2p_cell.clone(),
+                &space,
                 conductor_handle.clone(),
-                conductor_api.clone(),
                 managed_task_add_sender,
                 managed_task_stop_broadcaster,
-                countersigning_workspace.clone(),
             )
             .await;
 
@@ -163,13 +149,11 @@ impl Cell {
                 Self {
                     id,
                     conductor_api,
-                    env,
-                    cache,
+                    conductor_handle,
+                    space,
                     holochain_p2p_cell,
                     queue_triggers,
                     init_mutex: Default::default(),
-                    countersigning_workspace,
-                    incoming_op_hashes,
                 },
                 initial_queue_triggers,
             ))
@@ -184,7 +168,8 @@ impl Cell {
     pub async fn genesis<Ribosome>(
         id: CellId,
         conductor_handle: ConductorHandle,
-        cell_env: EnvWrite,
+        authored_env: DbWrite<DbKindAuthored>,
+        dht_env: DbWrite<DbKindDht>,
         ribosome: Ribosome,
         membrane_proof: Option<SerializedBytes>,
     ) -> CellResult<()>
@@ -196,10 +181,10 @@ impl Cell {
             .get_dna(id.dna_hash())
             .ok_or_else(|| DnaError::DnaMissing(id.dna_hash().to_owned()))?;
 
-        let conductor_api = CellConductorApi::new(conductor_handle, id.clone());
+        let conductor_api = CellConductorApi::new(conductor_handle.clone(), id.clone());
 
         // run genesis
-        let workspace = GenesisWorkspace::new(cell_env.clone())
+        let workspace = GenesisWorkspace::new(authored_env, dht_env)
             .map_err(ConductorApiError::from)
             .map_err(Box::new)?;
 
@@ -215,6 +200,13 @@ impl Cell {
             .map_err(Box::new)
             .map_err(ConductorApiError::from)
             .map_err(Box::new)?;
+
+        if let Some(trigger) = conductor_handle
+            .get_queue_consumer_workflows()
+            .integration_trigger(Arc::new(id.dna_hash().clone()))
+        {
+            trigger.trigger();
+        }
         Ok(())
     }
 
@@ -233,7 +225,7 @@ impl Cell {
     }
 
     /// Access a network sender that is partially applied to this cell's DnaHash/AgentPubKey
-    pub fn holochain_p2p_cell(&self) -> &holochain_p2p::HolochainP2pCell {
+    pub fn holochain_p2p_dna(&self) -> &holochain_p2p::HolochainP2pDna {
         &self.holochain_p2p_cell
     }
 
@@ -242,25 +234,31 @@ impl Cell {
     }
 
     pub(super) async fn delete_all_ephemeral_scheduled_fns(self: Arc<Self>) -> CellResult<()> {
+        let author = self.id.agent_pubkey().clone();
         Ok(self
-            .env
-            .async_commit(move |txn: &mut Transaction| delete_all_ephemeral_scheduled_fns(txn))
+            .space
+            .authored_env
+            .async_commit(move |txn: &mut Transaction| {
+                delete_all_ephemeral_scheduled_fns(txn, &author)
+            })
             .await?)
     }
 
     pub(super) async fn dispatch_scheduled_fns(self: Arc<Self>) {
         let now = Timestamp::now();
+        let author = self.id.agent_pubkey().clone();
         let lives = self
-            .env
+            .space
+            .authored_env
             .async_commit(move |txn: &mut Transaction| {
                 // Rescheduling should not fail as the data in the database
                 // should be valid schedules only.
-                reschedule_expired(txn, now)?;
-                let lives = live_scheduled_fns(txn, now);
+                reschedule_expired(txn, now, &author)?;
+                let lives = live_scheduled_fns(txn, now, &author);
                 // We know what to run so we can delete the ephemerals.
                 if lives.is_ok() {
                     // Failing to delete should rollback this attempt.
-                    delete_live_ephemeral_scheduled_fns(txn, now)?;
+                    delete_live_ephemeral_scheduled_fns(txn, now, &author)?;
                 }
                 lives
             })
@@ -296,9 +294,11 @@ impl Cell {
                 let results: Vec<CellResult<ZomeCallResult>> =
                     futures::future::join_all(tasks).await;
 
+                let author = self.id.agent_pubkey().clone();
                 // We don't do anything with errors in here.
                 let _ = self
-                    .env
+                    .space
+                    .authored_env
                     .async_commit(move |txn: &mut Transaction| {
                         for ((scheduled_fn, _), result) in lives.iter().zip(results.iter()) {
                             match result {
@@ -318,6 +318,7 @@ impl Cell {
                                     // For example if a zome returns a bad cron.
                                     if let Err(e) = schedule_fn(
                                         txn,
+                                        &author,
                                         scheduled_fn.clone(),
                                         Some(next_schedule),
                                         now,
@@ -351,7 +352,9 @@ impl Cell {
             | QueryOpHashes { .. }
             | QueryAgentInfoSignedNearBasis { .. }
             | QueryPeerDensity { .. }
+            | Publish { .. }
             | PutMetricDatum { .. }
+            | FetchOpData { .. }
             | QueryMetrics { .. } => {
                 // These events are aggregated over a set of cells, so need to be handled at the conductor level.
                 unreachable!()
@@ -376,25 +379,6 @@ impl Cell {
                 .instrument(debug_span!("call_remote"))
                 .await;
             }
-            Publish {
-                span_context,
-                respond,
-                request_validation_receipt,
-                countersigning_session,
-                ops,
-                ..
-            } => {
-                async {
-                    tracing::Span::set_current_context(span_context);
-                    let res = self
-                        .handle_publish(request_validation_receipt, countersigning_session, ops)
-                        .await
-                        .map_err(holochain_p2p::HolochainP2pError::other);
-                    respond.respond(Ok(async move { res }.boxed().into()));
-                }
-                .instrument(debug_span!("cell_handle_publish"))
-                .await;
-            }
             GetValidationPackage {
                 span_context: _,
                 respond,
@@ -499,22 +483,6 @@ impl Cell {
                 // and should reset the publish back off loop to its minimum.
                 self.queue_triggers.publish_dht_ops.reset_back_off();
             }
-            FetchOpData {
-                span_context: _,
-                respond,
-                op_hashes,
-                ..
-            } => {
-                async {
-                    let res = self
-                        .handle_fetch_op_data(op_hashes)
-                        .await
-                        .map_err(holochain_p2p::HolochainP2pError::other);
-                    respond.respond(Ok(async move { res }.boxed().into()));
-                }
-                .instrument(debug_span!("cell_handle_fetch_op_data"))
-                .await;
-            }
             SignNetworkData {
                 span_context: _,
                 respond,
@@ -549,41 +517,6 @@ impl Cell {
         Ok(())
     }
 
-    #[instrument(skip(self, request_validation_receipt, ops))]
-    /// we are receiving a "publish" event from the network
-    async fn handle_publish(
-        &self,
-        request_validation_receipt: bool,
-        countersigning_session: bool,
-        ops: Vec<(holo_hash::DhtOpHash, holochain_types::dht_op::DhtOp)>,
-    ) -> CellResult<()> {
-        // If this is a countersigning session then
-        // send it to the countersigning workflow otherwise
-        // send it to the incoming ops workflow.
-        if countersigning_session {
-            incoming_countersigning(
-                ops,
-                &self.countersigning_workspace,
-                self.queue_triggers.countersigning.clone(),
-            )
-            .map_err(Box::new)
-            .map_err(ConductorApiError::from)
-            .map_err(Box::new)?;
-        } else {
-            incoming_dht_ops_workflow(
-                &self.env,
-                Some(&self.incoming_op_hashes),
-                self.queue_triggers.sys_validation.clone(),
-                ops,
-                request_validation_receipt,
-            )
-            .await
-            .map_err(Box::new)
-            .map_err(ConductorApiError::from)
-            .map_err(Box::new)?;
-        }
-        Ok(())
-    }
     #[instrument(skip(self, signed_headers))]
     /// we are receiving a response from a countersigning authority
     async fn handle_countersigning_authority_response(
@@ -591,11 +524,12 @@ impl Cell {
         signed_headers: Vec<SignedHeader>,
     ) -> CellResult<()> {
         Ok(countersigning_success(
-            self.env.clone(),
+            self.space.authored_env.clone(),
+            self.space.dht_env.clone(),
             &self.holochain_p2p_cell,
             self.id.agent_pubkey().clone(),
             signed_headers,
-            self.queue_triggers.publish_dht_ops.clone(),
+            self.queue_triggers.clone(),
             self.conductor_api.signal_broadcaster().await,
         )
         .await
@@ -609,10 +543,10 @@ impl Cell {
         &self,
         header_hash: HeaderHash,
     ) -> CellResult<ValidationPackageResponse> {
-        let env: EnvRead = self.env.clone().into();
+        let env: DbRead<DbKindDht> = self.dht_env().clone().into();
 
         // Get the header
-        let mut cascade = Cascade::empty().with_vault(env.clone());
+        let mut cascade = Cascade::empty().with_dht(env.clone());
         let header = match cascade
             .retrieve_header(header_hash, Default::default())
             .await?
@@ -627,10 +561,11 @@ impl Cell {
         if header.author() == self.id.agent_pubkey() {
             validation_package::get_as_author(
                 header,
-                env,
-                self.cache.clone(),
+                self.space.authored_env.clone().into(),
+                self.dht_env().clone().into(),
+                self.space.cache.clone(),
                 &ribosome,
-                &self.conductor_api,
+                &(*self.conductor_handle),
                 &self.holochain_p2p_cell,
             )
             .await
@@ -639,7 +574,7 @@ impl Cell {
                 header,
                 env,
                 &ribosome.dna_file,
-                &self.conductor_api,
+                self.conductor_handle.as_ref(),
             )
             .await
         }
@@ -679,7 +614,7 @@ impl Cell {
         hash: EntryHash,
         options: holochain_p2p::event::GetOptions,
     ) -> CellResult<WireEntryOps> {
-        let env = self.env.clone();
+        let env = self.space.dht_env.clone();
         authority::handle_get_entry(env.into(), hash, options)
             .await
             .map_err(Into::into)
@@ -691,7 +626,7 @@ impl Cell {
         hash: HeaderHash,
         options: holochain_p2p::event::GetOptions,
     ) -> CellResult<WireElementOps> {
-        let env = self.env.clone();
+        let env = self.space.dht_env.clone();
         authority::handle_get_element(env.into(), hash, options)
             .await
             .map_err(Into::into)
@@ -718,7 +653,7 @@ impl Cell {
         options: holochain_p2p::event::GetLinksOptions,
     ) -> CellResult<WireLinkOps> {
         debug!(id = ?self.id());
-        let env = self.env.clone();
+        let env = self.space.dht_env.clone();
         authority::handle_get_links(env.into(), link_key, options)
             .await
             .map_err(Into::into)
@@ -731,7 +666,7 @@ impl Cell {
         query: ChainQueryFilter,
         options: holochain_p2p::event::GetActivityOptions,
     ) -> CellResult<AgentActivityResponse<HeaderHash>> {
-        let env = self.env.clone();
+        let env = self.space.dht_env.clone();
         authority::handle_get_agent_activity(env.into(), agent, query, options)
             .await
             .map_err(Into::into)
@@ -741,12 +676,13 @@ impl Cell {
     #[tracing::instrument(skip(self, receipt))]
     async fn handle_validation_receipt(&self, receipt: SerializedBytes) -> CellResult<()> {
         let receipt: SignedValidationReceipt = receipt.try_into()?;
-        tracing::debug!(from = ?receipt.receipt.validator, to = ?self.id.agent_pubkey(), hash = ?receipt.receipt.dht_op_hash);
+        tracing::debug!(from = ?receipt.receipt.validators, to = ?self.id.agent_pubkey(), hash = ?receipt.receipt.dht_op_hash);
 
         // Get the header for this op so we can check the entry type.
         let hash = receipt.receipt.dht_op_hash.clone();
         let header: Option<SignedHeader> = self
-            .env
+            .space
+            .authored_env
             .async_reader(move |txn| {
                 let h: Option<Vec<u8>> = txn
                     .query_row(
@@ -790,7 +726,8 @@ impl Cell {
             crate::core::workflow::publish_dht_ops_workflow::DEFAULT_RECEIPT_BUNDLE_SIZE,
         );
 
-        self.env
+        self.space
+            .dht_env
             .async_commit(move |txn| {
                 // Get the current count for this dhtop.
                 let receipt_count: usize = txn.query_row(
@@ -814,142 +751,6 @@ impl Cell {
         Ok(())
     }
 
-    #[instrument(skip(self))]
-    /// the network module is requesting a list of dht op hashes
-    /// Get the [`DhtOpHash`]es and authored timestamps for a given time window.
-    pub(super) async fn handle_query_op_hashes(
-        &self,
-        dht_arc_set: DhtArcSet,
-        window: TimeWindow,
-        include_limbo: bool,
-    ) -> CellResult<Vec<(DhtOpHash, Timestamp)>> {
-        let mut results = Vec::new();
-
-        // The exclusive window bounds.
-        let start = window.start;
-        let end = window.end;
-
-        let full = if include_limbo {
-            holochain_sqlite::sql::sql_cell::any::FETCH_OP_HASHES_FULL
-        } else {
-            holochain_sqlite::sql::sql_cell::integrated::FETCH_OP_HASHES_FULL
-        };
-
-        let continuous = if include_limbo {
-            holochain_sqlite::sql::sql_cell::any::FETCH_OP_HASHES_CONTINUOUS
-        } else {
-            holochain_sqlite::sql::sql_cell::integrated::FETCH_OP_HASHES_CONTINUOUS
-        };
-
-        let wrapped = if include_limbo {
-            holochain_sqlite::sql::sql_cell::any::FETCH_OP_HASHES_WRAPPED
-        } else {
-            holochain_sqlite::sql::sql_cell::integrated::FETCH_OP_HASHES_WRAPPED
-        };
-
-        // For each interval in the set, fetch the hashes and timestamps.
-        for interval in dht_arc_set.intervals() {
-            let result = self
-                .env()
-                .async_reader(move |txn| {
-                    DatabaseResult::Ok(match interval {
-                        ArcInterval::Full => txn
-                            .prepare_cached(full)?
-                            .query_map(
-                                named_params! {
-                                    ":from": start,
-                                    ":to": end,
-                                },
-                                |row| Ok((row.get("hash")?, row.get("authored_timestamp")?)),
-                            )?
-                            .collect::<rusqlite::Result<Vec<_>>>()?,
-                        ArcInterval::Bounded(start_loc, end_loc) => {
-                            let sql = if start_loc <= end_loc {
-                                continuous
-                            } else {
-                                wrapped
-                            };
-                            txn.prepare_cached(sql)?
-                                .query_map(
-                                    named_params! {
-                                        ":from": start,
-                                        ":to": end,
-                                        ":storage_start_loc": start_loc,
-                                        ":storage_end_loc": end_loc,
-                                    },
-                                    |row| Ok((row.get("hash")?, row.get("authored_timestamp")?)),
-                                )?
-                                .collect::<rusqlite::Result<Vec<_>>>()?
-                        }
-                        ArcInterval::Empty => Vec::new(),
-                    })
-                })
-                .await?;
-            results.extend(result);
-        }
-        Ok(results)
-    }
-
-    #[instrument(skip(self, op_hashes))]
-    /// The network module is requesting the content for dht ops
-    async fn handle_fetch_op_data(
-        &self,
-        op_hashes: Vec<holo_hash::DhtOpHash>,
-    ) -> CellResult<Vec<(holo_hash::DhtOpHash, holochain_types::dht_op::DhtOp)>> {
-        // FIXME: Test this query.
-        // TODO: SQL_PERF: Really on the fence about this query.
-        // It has the potential to be slow if data density is very high
-        // but this is ideally not the case for most apps so is it
-        // worth everyone paying the cost of asyncifying?
-        let results = self
-            .env()
-            .async_reader(move |txn| {
-                let mut positions = "?,".repeat(op_hashes.len());
-                positions.pop();
-                let sql = format!(
-                    "
-                SELECT DhtOp.hash, DhtOp.type AS dht_type,
-                Header.blob AS header_blob, Entry.blob AS entry_blob
-                FROM DHtOp
-                JOIN Header ON DhtOp.header_hash = Header.hash
-                LEFT JOIN Entry ON Header.entry_hash = Entry.hash
-                WHERE
-                DhtOp.when_integrated IS NOT NULL
-                AND
-                DhtOp.hash in ({})
-                ",
-                    positions
-                );
-                let mut stmt = txn.prepare(&sql)?;
-                let r = stmt
-                    .query_and_then(rusqlite::params_from_iter(op_hashes.into_iter()), |row| {
-                        let header = from_blob::<SignedHeader>(row.get("header_blob")?)?;
-                        let op_type: DhtOpType = row.get("dht_type")?;
-                        let hash: DhtOpHash = row.get("hash")?;
-                        // Check the entry isn't private before gossiping it.
-                        let mut entry: Option<Entry> = None;
-                        if header
-                            .0
-                            .entry_type()
-                            .filter(|et| *et.visibility() == EntryVisibility::Public)
-                            .is_some()
-                        {
-                            let e: Option<Vec<u8>> = row.get("entry_blob")?;
-                            entry = match e {
-                                Some(entry) => Some(from_blob::<Entry>(entry)?),
-                                None => None,
-                            };
-                        }
-                        let op = DhtOp::from_type(op_type, header, entry)?;
-                        StateQueryResult::Ok((hash, op))
-                    })?
-                    .collect::<StateQueryResult<Vec<_>>>()?;
-                StateQueryResult::Ok(r)
-            })
-            .await?;
-        Ok(results)
-    }
-
     /// the network module would like this cell/agent to sign some data
     #[tracing::instrument(skip(self))]
     async fn handle_sign_network_data(&self) -> CellResult<Signature> {
@@ -985,38 +786,41 @@ impl Cell {
     pub async fn call_zome(
         &self,
         call: ZomeCall,
-        workspace_lock: Option<HostFnWorkspace>,
+        workspace_lock: Option<SourceChainWorkspace>,
     ) -> CellResult<ZomeCallResult> {
         // Check if init has run if not run it
         self.check_or_run_zome_init().await?;
 
-        let arc = self.env();
-        let keystore = arc.keystore().clone();
+        let keystore = self.conductor_api.keystore().clone();
 
         // If there is no existing zome call then this is the root zome call
         let is_root_zome_call = workspace_lock.is_none();
         let workspace_lock = match workspace_lock {
             Some(l) => l,
             None => {
-                HostFnWorkspace::new(
-                    self.env().clone(),
+                SourceChainWorkspace::new(
+                    self.authored_env().clone(),
+                    self.dht_env().clone(),
                     self.cache().clone(),
+                    keystore.clone(),
                     self.id.agent_pubkey().clone(),
                 )
                 .await?
             }
         };
 
-        let conductor_api = self.conductor_api.clone();
+        let conductor_handle = self.conductor_handle.clone();
         let signal_tx = self.signal_broadcaster().await;
         let ribosome = self.get_ribosome().await?;
-        let invocation = ZomeCallInvocation::from_interface_call(conductor_api.clone(), call).await;
+        let invocation =
+            ZomeCallInvocation::from_interface_call(self.conductor_api.clone(), call).await;
 
         let args = CallZomeWorkflowArgs {
+            cell_id: self.id.clone(),
             ribosome,
             invocation,
             signal_tx,
-            conductor_api,
+            conductor_handle,
             is_root_zome_call,
         };
         Ok(call_zome_workflow(
@@ -1043,14 +847,15 @@ impl Cell {
         .map_err(|_| CellError::InitTimeout)?;
 
         // If not run it
-        let env = self.env.clone();
-        let keystore = env.keystore().clone();
+        let keystore = self.conductor_api.keystore().clone();
         let id = self.id.clone();
-        let conductor_api = self.conductor_api.clone();
+        let conductor_handle = self.conductor_handle.clone();
         // Create the workspace
-        let workspace = HostFnWorkspace::new(
-            self.env().clone(),
+        let workspace = SourceChainWorkspace::new(
+            self.authored_env().clone(),
+            self.dht_env().clone(),
             self.cache().clone(),
+            keystore.clone(),
             id.agent_pubkey().clone(),
         )
         .await?;
@@ -1062,7 +867,7 @@ impl Cell {
         trace!("running init");
 
         // get the dna
-        let dna_file = conductor_api
+        let dna_file = conductor_handle
             .get_dna(id.dna_hash())
             .ok_or_else(|| DnaError::DnaMissing(id.dna_hash().to_owned()))?;
         let dna_def = dna_file.dna_def().clone();
@@ -1074,7 +879,7 @@ impl Cell {
         let args = InitializeZomesWorkflowArgs {
             dna_def,
             ribosome,
-            conductor_api,
+            conductor_handle,
         };
         let init_result =
             initialize_zomes_workflow(workspace, self.holochain_p2p_cell.clone(), keystore, args)
@@ -1100,28 +905,14 @@ impl Cell {
     //        TaskManager can have these Cell TaskManagers as children.
     //        [ B-04176 ]
     pub async fn cleanup(&self) -> CellResult<()> {
-        use holochain_p2p::HolochainP2pCellT;
-        self.holochain_p2p_cell().leave().await?;
+        use holochain_p2p::HolochainP2pDnaT;
+        self.holochain_p2p_dna()
+            .leave(self.id.agent_pubkey().clone())
+            .await?;
         tracing::info!("Cell removed, but cleanup is not yet fully implemented.");
         Ok(())
     }
 
-    /// Delete all data associated with this Cell by DELETING the associated
-    /// LMDB environment. Completely reverses Cell creation.
-    /// NB: This is NOT meant to be a Drop impl! This destroys all data
-    ///     associated with a Cell, i.e. this Cell can never be instantiated again!
-    #[tracing::instrument(skip(self))]
-    pub async fn destroy(self) -> CellResult<()> {
-        self.cleanup().await?;
-        let path = self.env.path().clone();
-        // Delete directory
-        self.env
-            .remove()
-            .await
-            .map_err(|e| CellError::Cleanup(e.to_string(), path))?;
-        Ok(())
-    }
-
     /// Instantiate a Ribosome for use by this Cell's workflows
     // TODO: reevaluate once Workflows are fully implemented (after B-01567)
     pub(crate) async fn get_ribosome(&self) -> CellResult<RealRibosome> {
@@ -1131,14 +922,19 @@ impl Cell {
         }
     }
 
-    /// Accessor for the database backing this Cell
+    /// Accessor for the authored database backing this Cell
     // TODO: reevaluate once Workflows are fully implemented (after B-01567)
-    pub(crate) fn env(&self) -> &EnvWrite {
-        &self.env
+    pub(crate) fn authored_env(&self) -> &DbWrite<DbKindAuthored> {
+        &self.space.authored_env
     }
 
-    pub(crate) fn cache(&self) -> &EnvWrite {
-        &self.cache
+    /// Accessor for the authored database backing this Cell
+    pub(crate) fn dht_env(&self) -> &DbWrite<DbKindDht> {
+        &self.space.dht_env
+    }
+
+    pub(crate) fn cache(&self) -> &DbWrite<DbKindCache> {
+        &self.space.cache
     }
 
     #[cfg(any(test, feature = "test_utils"))]
