@@ -384,7 +384,7 @@ pub mod test {
         let respond = Respond::Request(Box::new(respond));
         let msg = (msg, respond);
         handle_incoming_message(msg, admin_api).await.unwrap();
-        conductor_handle.shutdown().await;
+        conductor_handle.shutdown();
     }
 
     #[tokio::test(flavor = "multi_thread")]
@@ -412,7 +412,7 @@ pub mod test {
         let respond = Respond::Request(Box::new(respond));
         let msg = (msg, respond);
         handle_incoming_message(msg, admin_api).await.unwrap();
-        conductor_handle.shutdown().await;
+        conductor_handle.shutdown();
     }
 
     #[ignore = "stub"]
@@ -480,8 +480,8 @@ pub mod test {
         handle_incoming_message(msg, app_api).await.unwrap();
         // the time here should be almost the same (about +0.1ms) vs. the raw real_ribosome call
         // the overhead of a websocket request locally is small
-        let shutdown = handle.take_shutdown_handle().await.unwrap();
-        handle.shutdown().await;
+        let shutdown = handle.take_shutdown_handle().unwrap();
+        handle.shutdown();
         shutdown.await.unwrap().unwrap();
     }
 
@@ -520,7 +520,7 @@ pub mod test {
             .return_const(());
         let (_tmpdir, conductor_handle) =
             setup_admin_fake_cells(cell_ids_with_proofs, dna_store).await;
-        let shutdown = conductor_handle.take_shutdown_handle().await.unwrap();
+        let shutdown = conductor_handle.take_shutdown_handle().unwrap();
         let app_id = "test app".to_string();
 
         // Activate the app
@@ -615,7 +615,7 @@ pub mod test {
             assert!(false);
         }
 
-        conductor_handle.shutdown().await;
+        conductor_handle.shutdown();
         shutdown.await.unwrap().unwrap();
     }
 
@@ -623,7 +623,7 @@ pub mod test {
     async fn attach_app_interface() {
         observability::test_run().ok();
         let (_tmpdir, conductor_handle) = setup_admin().await;
-        let shutdown = conductor_handle.take_shutdown_handle().await.unwrap();
+        let shutdown = conductor_handle.take_shutdown_handle().unwrap();
         let admin_api = RealAdminInterfaceApi::new(conductor_handle.clone());
         let msg = AdminRequest::AttachAppInterface { port: None };
         let msg = msg.try_into().unwrap();
@@ -635,7 +635,7 @@ pub mod test {
         let respond = Respond::Request(Box::new(respond));
         let msg = (msg, respond);
         handle_incoming_message(msg, admin_api).await.unwrap();
-        conductor_handle.shutdown().await;
+        conductor_handle.shutdown();
         shutdown.await.unwrap().unwrap();
     }
 
@@ -663,7 +663,7 @@ pub mod test {
         let (_tmpdir, conductor_handle) =
             setup_admin_fake_cells(vec![(cell_id.clone(), None)], dna_store).await;
         let conductor_handle = activate(conductor_handle).await;
-        let shutdown = conductor_handle.take_shutdown_handle().await.unwrap();
+        let shutdown = conductor_handle.take_shutdown_handle().unwrap();
         // Allow agents time to join
         tokio::time::sleep(std::time::Duration::from_secs(2)).await;
 
@@ -683,7 +683,7 @@ pub mod test {
         let respond = Respond::Request(Box::new(respond));
         let msg = (msg, respond);
         handle_incoming_message(msg, admin_api).await.unwrap();
-        conductor_handle.shutdown().await;
+        conductor_handle.shutdown();
         shutdown.await.unwrap().unwrap();
     }
 
