@@ -12,7 +12,6 @@ use holochain_p2p::AgentPubKeyExt;
 use holochain_sqlite::prelude::*;
 use holochain_state::prelude::StateMutationResult;
 use holochain_state::prelude::StateQueryResult;
-use holochain_types::prelude::*;
 use holochain_zome_types::CellId;
 use kitsune_p2p::KitsuneBinType;
 use std::sync::Arc;
@@ -40,14 +39,17 @@ pub enum P2pBatchError {
 
 /// Inject multiple agent info entries into the peer store
 pub async fn inject_agent_infos<'iter, I: IntoIterator<Item = &'iter AgentInfoSigned> + Send>(
-    env: EnvWrite,
+    env: DbWrite<DbKindP2pAgentStore>,
     iter: I,
 ) -> StateMutationResult<()> {
     Ok(p2p_put_all(&env, iter.into_iter()).await?)
 }
 
 /// Inject multiple agent info entries into the peer store in batches.
-pub async fn p2p_put_all_batch(env: EnvWrite, rx: tokio::sync::mpsc::Receiver<P2pBatch>) {
+pub async fn p2p_put_all_batch(
+    env: DbWrite<DbKindP2pAgentStore>,
+    rx: tokio::sync::mpsc::Receiver<P2pBatch>,
+) {
     let stream = tokio_stream::wrappers::ReceiverStream::new(rx);
     let mut stream = stream.ready_chunks(100);
     while let Some(batch) = stream.next().await {
@@ -95,13 +97,15 @@ pub async fn p2p_put_all_batch(env: EnvWrite, rx: tokio::sync::mpsc::Receiver<P2
 }
 
 /// Helper function to get all the peer data from this conductor
-pub async fn all_agent_infos(env: EnvRead) -> StateQueryResult<Vec<AgentInfoSigned>> {
+pub async fn all_agent_infos(
+    env: DbRead<DbKindP2pAgentStore>,
+) -> StateQueryResult<Vec<AgentInfoSigned>> {
     env.async_reader(|r| Ok(r.p2p_list_agents()?)).await
 }
 
 /// Helper function to get a single agent info
 pub async fn get_single_agent_info(
-    env: EnvRead,
+    env: DbRead<DbKindP2pAgentStore>,
     _space: DnaHash,
     agent: AgentPubKey,
 ) -> StateQueryResult<Option<AgentInfoSigned>> {
@@ -112,7 +116,7 @@ pub async fn get_single_agent_info(
 
 /// Interconnect every provided pair of conductors via their peer store databases
 #[cfg(any(test, feature = "test_utils"))]
-pub async fn exchange_peer_info(envs: Vec<EnvWrite>) {
+pub async fn exchange_peer_info(envs: Vec<DbWrite<DbKindP2pAgentStore>>) {
     for (i, a) in envs.iter().enumerate() {
         for (j, b) in envs.iter().enumerate() {
             if i == j {
@@ -136,7 +140,7 @@ pub async fn exchange_peer_info(envs: Vec<EnvWrite>) {
 
 /// Get agent info for a single agent
 pub fn get_agent_info_signed(
-    environ: EnvWrite,
+    environ: DbWrite<DbKindP2pAgentStore>,
     _kitsune_space: Arc<kitsune_p2p::KitsuneSpace>,
     kitsune_agent: Arc<kitsune_p2p::KitsuneAgent>,
 ) -> ConductorResult<Option<AgentInfoSigned>> {
@@ -145,7 +149,7 @@ pub fn get_agent_info_signed(
 
 /// Get all agent info for a single space
 pub fn list_all_agent_info(
-    environ: EnvWrite,
+    environ: DbWrite<DbKindP2pAgentStore>,
     _kitsune_space: Arc<kitsune_p2p::KitsuneSpace>,
 ) -> ConductorResult<Vec<AgentInfoSigned>> {
     Ok(environ.conn()?.p2p_list_agents()?)
@@ -153,7 +157,7 @@ pub fn list_all_agent_info(
 
 /// Get all agent info for a single space near a basis loc
 pub fn list_all_agent_info_signed_near_basis(
-    environ: EnvWrite,
+    environ: DbWrite<DbKindP2pAgentStore>,
     _kitsune_space: Arc<kitsune_p2p::KitsuneSpace>,
     basis_loc: u32,
     limit: u32,
@@ -164,7 +168,7 @@ pub fn list_all_agent_info_signed_near_basis(
 /// Get the peer density an agent is currently seeing within
 /// a given [`DhtArc`]
 pub fn query_peer_density(
-    env: EnvWrite,
+    env: DbWrite<DbKindP2pAgentStore>,
     kitsune_space: Arc<kitsune_p2p::KitsuneSpace>,
     dht_arc: DhtArc,
 ) -> ConductorResult<PeerDensity> {
@@ -193,7 +197,7 @@ pub fn query_peer_density(
 
 /// Put single agent info into store
 pub async fn put_agent_info_signed(
-    environ: EnvWrite,
+    environ: DbWrite<DbKindP2pAgentStore>,
     agent_info_signed: kitsune_p2p::agent_store::AgentInfoSigned,
 ) -> ConductorResult<()> {
     Ok(p2p_put(&environ, &agent_info_signed).await?)
@@ -211,7 +215,10 @@ fn is_expired(now: u64, info: &AgentInfoSigned) -> bool {
 }
 
 /// Dump the agents currently in the peer store
-pub async fn dump_state(env: EnvRead, cell_id: Option<CellId>) -> StateQueryResult<P2pAgentsDump> {
+pub async fn dump_state(
+    env: DbRead<DbKindP2pAgentStore>,
+    cell_id: Option<CellId>,
+) -> StateQueryResult<P2pAgentsDump> {
     use std::fmt::Write;
     let cell_id = cell_id.map(|c| c.into_dna_and_agent()).map(|c| {
         (
