@@ -10,7 +10,7 @@ use std::time::SystemTime;
 
 /// Record a p2p metric datum
 pub async fn put_metric_datum(
-    env: EnvWrite,
+    env: DbWrite<DbKindP2pMetrics>,
     agent: AgentPubKey,
     metric: MetricKind,
     timestamp: SystemTime,
@@ -24,7 +24,7 @@ pub async fn put_metric_datum(
 
 /// Query the p2p_metrics database in a variety of ways
 pub async fn query_metrics(
-    env: EnvWrite,
+    env: DbWrite<DbKindP2pMetrics>,
     query: MetricQuery,
 ) -> ConductorResult<MetricQueryAnswer> {
     Ok(env
