@@ -9,25 +9,25 @@ use tracing::*;
 
 /// Spawn the QueueConsumer for SysValidation workflow
 #[instrument(skip(
-    env,
-    cache,
+    workspace,
+    space,
     conductor_handle,
     stop,
     trigger_app_validation,
     network,
-    conductor_api
 ))]
 pub fn spawn_sys_validation_consumer(
-    env: EnvWrite,
-    cache: EnvWrite,
+    workspace: SysValidationWorkspace,
+    space: Space,
     conductor_handle: ConductorHandle,
     mut stop: sync::broadcast::Receiver<()>,
     trigger_app_validation: TriggerSender,
-    network: HolochainP2pCell,
-    conductor_api: impl CellConductorApiT + 'static,
+    network: HolochainP2pDna,
 ) -> (TriggerSender, JoinHandle<ManagedTaskResult>) {
     let (tx, mut rx) = TriggerSender::new();
     let trigger_self = tx.clone();
+    let workspace = Arc::new(workspace);
+    let space = Arc::new(space);
     let handle = tokio::spawn(async move {
         loop {
             // Wait for next job
@@ -39,26 +39,18 @@ pub fn spawn_sys_validation_consumer(
             }
 
             // Run the workflow
-            let workspace = SysValidationWorkspace::new(env.clone(), cache.clone());
             match sys_validation_workflow(
-                workspace,
+                workspace.clone(),
+                space.clone(),
                 trigger_app_validation.clone(),
                 trigger_self.clone(),
                 network.clone(),
-                conductor_api.clone(),
+                &(*conductor_handle),
             )
             .await
             {
                 Ok(WorkComplete::Incomplete) => trigger_self.trigger(),
-                Err(err) => {
-                    handle_workflow_error(
-                        conductor_handle.clone(),
-                        network.cell_id(),
-                        err,
-                        "sys_validation failure",
-                    )
-                    .await?
-                }
+                Err(err) => handle_workflow_error(err)?,
                 _ => (),
             };
         }
