@@ -22,7 +22,7 @@ pub fn must_get_entry<'a>(
             // timeouts must be handled by the network
             tokio_helper::block_forever_on(async move {
                 let workspace = call_context.host_context.workspace();
-                let mut cascade = Cascade::from_workspace_network(workspace, network);
+                let mut cascade = Cascade::from_workspace_network(&workspace, network);
                 match cascade
                     .retrieve_entry(entry_hash.clone(),
                     // Set every GetOptions manually here.
@@ -188,8 +188,8 @@ pub mod test {
             Some(author),
         )
         .await;
-        let cell_network = test_network.cell_network();
-        host_access.network = cell_network;
+        let dna_network = test_network.dna_network();
+        host_access.network = dna_network;
 
         let mut validate_invocation = fixt!(ValidateInvocation);
         validate_invocation.element = Arc::new(header_reference_element.clone());
@@ -197,7 +197,7 @@ pub mod test {
         validate_invocation.entry_def_id = Some(EntryDefId::App("header_reference".into()));
         let mut validate_host_access = fixt!(ValidateHostAccess);
         validate_host_access.network = host_access.network.clone();
-        validate_host_access.workspace = host_access.workspace.clone();
+        validate_host_access.workspace = host_access.workspace.clone().into();
 
         let header_reference_validate_result = ribosome.run_validate(validate_host_access.clone(), validate_invocation.clone()).unwrap();
 
