@@ -1,6 +1,6 @@
 use super::*;
-use crate::conductor::api::error::ConductorApiError;
-use crate::conductor::api::MockCellConductorApi;
+use crate::conductor::handle::MockConductorHandleT;
+use crate::conductor::space::TestSpaces;
 use crate::test_utils::fake_genesis;
 use ::fixt::prelude::*;
 use error::SysValidationError;
@@ -8,8 +8,9 @@ use error::SysValidationError;
 use holochain_keystore::AgentPubKeyExt;
 use holochain_serialized_bytes::SerializedBytes;
 use holochain_state::prelude::fresh_reader_test;
+use holochain_state::prelude::test_authored_env;
 use holochain_state::prelude::test_cache_env;
-use holochain_state::prelude::test_cell_env;
+use holochain_state::prelude::test_dht_env;
 use holochain_wasm_test_utils::TestWasm;
 use holochain_zome_types::Header;
 use matches::assert_matches;
@@ -59,15 +60,18 @@ async fn check_previous_header() {
 
 #[tokio::test(flavor = "multi_thread")]
 async fn check_valid_if_dna_test() {
-    let tmp = test_cell_env();
+    let tmp = test_authored_env();
+    let tmp_dht = test_dht_env();
     let tmp_cache = test_cache_env();
-    let env: EnvRead = tmp.env().into();
+    let keystore = test_keystore();
+    let env = tmp.env();
     // Test data
     let _activity_return = vec![fixt!(HeaderHash)];
 
     // Empty store not dna
     let header = fixt!(CreateLink);
-    let workspace = SysValidationWorkspace::new(env.clone().into(), tmp_cache.env());
+    let workspace =
+        SysValidationWorkspace::new(env.clone().into(), tmp_dht.env().into(), tmp_cache.env());
 
     assert_matches!(
         check_valid_if_dna(&header.clone().into(), &workspace).await,
@@ -79,8 +83,12 @@ async fn check_valid_if_dna_test() {
         Ok(())
     );
 
-    fake_genesis(env.clone().into()).await.unwrap();
-    env.conn()
+    fake_genesis(env.clone().into(), tmp_dht.env(), keystore)
+        .await
+        .unwrap();
+    tmp_dht
+        .env()
+        .conn()
         .unwrap()
         .execute("UPDATE DhtOp SET when_integrated = 0", [])
         .unwrap();
@@ -300,36 +308,28 @@ async fn check_app_entry_type_test() {
     entry_def.visibility = EntryVisibility::Public;
 
     // Setup mock conductor
-    let mut conductor_api = MockCellConductorApi::new();
-    conductor_api.expect_cell_id().return_const(fixt!(CellId));
+    let mut conductor_handle = MockConductorHandleT::new();
     // # No dna or entry def
-    conductor_api.expect_sync_get_entry_def().return_const(None);
-    conductor_api.expect_sync_get_dna().return_const(None);
-    conductor_api
-        .expect_sync_get_this_dna()
-        .returning(move || Err(ConductorApiError::DnaMissing(dna_hash.clone())));
+    conductor_handle.expect_get_entry_def().return_const(None);
+    conductor_handle.expect_get_dna().return_const(None);
 
     // ## Dna is missing
     let aet = AppEntryType::new(0.into(), 0.into(), EntryVisibility::Public);
     assert_matches!(
-        check_app_entry_type(&aet, &conductor_api).await,
-        Err(SysValidationError::ConductorApiError(e))
-        if matches!(*e, ConductorApiError::DnaMissing(_))
+        check_app_entry_type(&dna_hash, &aet, &conductor_handle).await,
+        Err(SysValidationError::DnaMissing(_))
     );
 
     // # Dna but no entry def in buffer
     // ## ZomeId out of range
-    conductor_api.checkpoint();
-    conductor_api.expect_sync_get_entry_def().return_const(None);
-    conductor_api
-        .expect_sync_get_dna()
+    conductor_handle.checkpoint();
+    conductor_handle.expect_get_entry_def().return_const(None);
+    conductor_handle
+        .expect_get_dna()
         .return_const(Some(dna_file.clone()));
-    conductor_api
-        .expect_sync_get_this_dna()
-        .returning(move || Ok(dna_file.clone()));
     let aet = AppEntryType::new(0.into(), 1.into(), EntryVisibility::Public);
     assert_matches!(
-        check_app_entry_type(&aet, &conductor_api).await,
+        check_app_entry_type(&dna_hash, &aet, &conductor_handle).await,
         Err(SysValidationError::ValidationOutcome(
             ValidationOutcome::ZomeId(_)
         ))
@@ -338,7 +338,7 @@ async fn check_app_entry_type_test() {
     // ## EntryId is out of range
     let aet = AppEntryType::new(10.into(), 0.into(), EntryVisibility::Public);
     assert_matches!(
-        check_app_entry_type(&aet, &conductor_api).await,
+        check_app_entry_type(&dna_hash, &aet, &conductor_handle).await,
         Err(SysValidationError::ValidationOutcome(
             ValidationOutcome::EntryDefId(_)
         ))
@@ -346,23 +346,29 @@ async fn check_app_entry_type_test() {
 
     // ## EntryId is in range for dna
     let aet = AppEntryType::new(0.into(), 0.into(), EntryVisibility::Public);
-    assert_matches!(check_app_entry_type(&aet, &conductor_api).await, Ok(_));
+    assert_matches!(
+        check_app_entry_type(&dna_hash, &aet, &conductor_handle).await,
+        Ok(_)
+    );
     let aet = AppEntryType::new(0.into(), 0.into(), EntryVisibility::Private);
     assert_matches!(
-        check_app_entry_type(&aet, &conductor_api).await,
+        check_app_entry_type(&dna_hash, &aet, &conductor_handle).await,
         Err(SysValidationError::ValidationOutcome(
             ValidationOutcome::EntryVisibility(_)
         ))
     );
 
     // # Add an entry def to the buffer
-    conductor_api
-        .expect_sync_get_entry_def()
+    conductor_handle
+        .expect_get_entry_def()
         .return_const(Some(entry_def));
 
     // ## Can get the entry from the entry def
     let aet = AppEntryType::new(0.into(), 0.into(), EntryVisibility::Public);
-    assert_matches!(check_app_entry_type(&aet, &conductor_api).await, Ok(_));
+    assert_matches!(
+        check_app_entry_type(&dna_hash, &aet, &conductor_handle).await,
+        Ok(_)
+    );
 }
 
 #[tokio::test(flavor = "multi_thread")]
@@ -382,44 +388,43 @@ async fn check_entry_not_private_test() {
 
 #[tokio::test(flavor = "multi_thread")]
 async fn incoming_ops_filters_private_entry() {
-    let vault = test_cell_env();
+    let dna = fixt!(DnaHash);
+    let spaces = TestSpaces::new([dna.clone()]);
+    let space = Arc::new(spaces.test_spaces[&dna].space.clone());
+    let vault = space.dht_env.clone();
+    let keystore = test_keystore();
     let (tx, _rx) = TriggerSender::new();
 
     let private_entry = fixt!(Entry);
     let mut create = fixt!(Create);
-    let author = vault
-        .env()
-        .keystore()
-        .new_sign_keypair_random()
-        .await
-        .unwrap();
+    let author = keystore.new_sign_keypair_random().await.unwrap();
     let aet = AppEntryType::new(0.into(), 0.into(), EntryVisibility::Private);
     create.entry_type = EntryType::App(aet);
     create.entry_hash = EntryHash::with_data_sync(&private_entry);
     create.author = author.clone();
     let header = Header::Create(create);
-    let signature = author.sign(&vault.env().keystore(), &header).await.unwrap();
+    let signature = author.sign(&keystore, &header).await.unwrap();
 
     let shh =
         SignedHeaderHashed::with_presigned(HeaderHashed::from_content_sync(header), signature);
     let el = Element::new(shh, Some(private_entry));
 
-    let ops_sender = IncomingDhtOpSender::new(vault.env(), tx.clone());
+    let ops_sender = IncomingDhtOpSender::new(space.clone(), tx.clone());
     ops_sender.send_store_entry(el.clone()).await.unwrap();
-    let num_ops: usize = fresh_reader_test(vault.env(), |txn| {
+    let num_ops: usize = fresh_reader_test(vault.clone(), |txn| {
         txn.query_row("SELECT COUNT(rowid) FROM DhtOp", [], |row| row.get(0))
             .unwrap()
     });
     assert_eq!(num_ops, 0);
 
-    let ops_sender = IncomingDhtOpSender::new(vault.env(), tx.clone());
+    let ops_sender = IncomingDhtOpSender::new(space.clone(), tx.clone());
     ops_sender.send_store_element(el.clone()).await.unwrap();
-    let num_ops: usize = fresh_reader_test(vault.env(), |txn| {
+    let num_ops: usize = fresh_reader_test(vault.clone(), |txn| {
         txn.query_row("SELECT COUNT(rowid) FROM DhtOp", [], |row| row.get(0))
             .unwrap()
     });
     assert_eq!(num_ops, 1);
-    let num_entries: usize = fresh_reader_test(vault.env(), |txn| {
+    let num_entries: usize = fresh_reader_test(vault.clone(), |txn| {
         txn.query_row("SELECT COUNT(rowid) FROM Entry", [], |row| row.get(0))
             .unwrap()
     });
