@@ -1,5 +1,5 @@
 use super::error::WorkflowResult;
-use crate::conductor::api::CellConductorApiT;
+use crate::conductor::ConductorHandle;
 use crate::core::ribosome::guest_callback::init::InitHostAccess;
 use crate::core::ribosome::guest_callback::init::InitInvocation;
 use crate::core::ribosome::guest_callback::init::InitResult;
@@ -7,35 +7,34 @@ use crate::core::ribosome::guest_callback::post_commit::send_post_commit;
 use crate::core::ribosome::RibosomeT;
 use derive_more::Constructor;
 use holochain_keystore::MetaLairClient;
-use holochain_p2p::HolochainP2pCell;
+use holochain_p2p::HolochainP2pDna;
 use holochain_state::host_fn_workspace::HostFnWorkspace;
+use holochain_state::host_fn_workspace::SourceChainWorkspace;
 use holochain_types::prelude::*;
 use holochain_zome_types::header::builder;
 use tracing::*;
 
-#[derive(Constructor, Debug)]
-pub struct InitializeZomesWorkflowArgs<Ribosome, C>
+#[derive(Constructor)]
+pub struct InitializeZomesWorkflowArgs<Ribosome>
 where
     Ribosome: RibosomeT + Send + 'static,
-    C: CellConductorApiT + Clone,
 {
     pub dna_def: DnaDef,
     pub ribosome: Ribosome,
-    pub conductor_api: C,
+    pub conductor_handle: ConductorHandle,
 }
 
 #[instrument(skip(network, keystore, workspace, args))]
-pub async fn initialize_zomes_workflow<Ribosome, C>(
-    workspace: HostFnWorkspace,
-    network: HolochainP2pCell,
+pub async fn initialize_zomes_workflow<Ribosome>(
+    workspace: SourceChainWorkspace,
+    network: HolochainP2pDna,
     keystore: MetaLairClient,
-    args: InitializeZomesWorkflowArgs<Ribosome, C>,
+    args: InitializeZomesWorkflowArgs<Ribosome>,
 ) -> WorkflowResult<InitResult>
 where
     Ribosome: RibosomeT + Send + 'static,
-    C: CellConductorApiT,
 {
-    let conductor_api = args.conductor_api.clone();
+    let conductor_handle = args.conductor_handle.clone();
     let result =
         initialize_zomes_workflow_inner(workspace.clone(), network.clone(), keystore.clone(), args)
             .await?;
@@ -44,30 +43,38 @@ where
 
     // only commit if the result was successful
     if result == InitResult::Pass {
-        let flushed_headers = workspace.clone().flush(&network).await?;
-        send_post_commit(conductor_api, workspace, network, keystore, flushed_headers).await?;
+        let flushed_headers = HostFnWorkspace::from(workspace.clone())
+            .flush(&network)
+            .await?;
+        send_post_commit(
+            conductor_handle,
+            workspace,
+            network,
+            keystore,
+            flushed_headers,
+        )
+        .await?;
     }
     Ok(result)
 }
 
-async fn initialize_zomes_workflow_inner<Ribosome, C>(
-    workspace: HostFnWorkspace,
-    network: HolochainP2pCell,
+async fn initialize_zomes_workflow_inner<Ribosome>(
+    workspace: SourceChainWorkspace,
+    network: HolochainP2pDna,
     keystore: MetaLairClient,
-    args: InitializeZomesWorkflowArgs<Ribosome, C>,
+    args: InitializeZomesWorkflowArgs<Ribosome>,
 ) -> WorkflowResult<InitResult>
 where
     Ribosome: RibosomeT + Send + 'static,
-    C: CellConductorApiT,
 {
     let InitializeZomesWorkflowArgs {
         dna_def,
         ribosome,
-        conductor_api,
+        conductor_handle,
     } = args;
     // Call the init callback
     let result = {
-        let host_access = InitHostAccess::new(workspace.clone(), keystore, network.clone());
+        let host_access = InitHostAccess::new(workspace.clone().into(), keystore, network.clone());
         let invocation = InitInvocation { dna_def };
         ribosome.run_init(host_access, invocation)?
     };
@@ -89,7 +96,7 @@ where
     .await??;
 
     // TODO: Validate scratch items
-    super::inline_validation(workspace, network, conductor_api, None, ribosome).await?;
+    super::inline_validation(workspace, network, conductor_handle, None, ribosome).await?;
 
     Ok(result)
 }
@@ -99,7 +106,6 @@ pub mod tests {
     use std::sync::Arc;
 
     use super::*;
-    use crate::conductor::api::CellConductorApi;
     use crate::conductor::handle::MockConductorHandleT;
     use crate::core::ribosome::MockRibosomeT;
     use crate::fixt::DnaDefFixturator;
@@ -108,40 +114,53 @@ pub mod tests {
     use crate::test_utils::fake_genesis;
     use ::fixt::prelude::*;
     use fixt::Unpredictable;
-    use holo_hash::DnaHash;
-    use holochain_p2p::HolochainP2pCellFixturator;
+    use holochain_p2p::HolochainP2pDnaFixturator;
+    use holochain_state::prelude::test_authored_env;
     use holochain_state::prelude::test_cache_env;
-    use holochain_state::prelude::test_cell_env;
+    use holochain_state::prelude::test_dht_env;
     use holochain_state::prelude::SourceChain;
     use holochain_types::prelude::DnaDefHashed;
     use holochain_wasm_test_utils::TestWasm;
     use holochain_zome_types::fake_agent_pubkey_1;
-    use holochain_zome_types::CellId;
     use holochain_zome_types::Header;
     use matches::assert_matches;
 
-    async fn get_chain(cell: &SweetCell) -> SourceChain {
-        SourceChain::new(cell.env().clone().into(), cell.agent_pubkey().clone())
-            .await
-            .unwrap()
+    async fn get_chain(cell: &SweetCell, keystore: MetaLairClient) -> SourceChain {
+        SourceChain::new(
+            cell.authored_env().clone(),
+            cell.dht_env().clone(),
+            keystore,
+            cell.agent_pubkey().clone(),
+        )
+        .await
+        .unwrap()
     }
 
     #[tokio::test(flavor = "multi_thread")]
     async fn adds_init_marker() {
-        let test_env = test_cell_env();
+        let test_env = test_authored_env();
         let test_cache = test_cache_env();
+        let test_dht = test_dht_env();
+        let keystore = test_keystore();
         let env = test_env.env();
         let author = fake_agent_pubkey_1();
 
         // Genesis
-        fake_genesis(env.clone()).await.unwrap();
-
-        let workspace = HostFnWorkspace::new(env.clone(), test_cache.env(), author.clone())
+        fake_genesis(env.clone(), test_dht.env(), keystore.clone())
             .await
             .unwrap();
+
+        let workspace = SourceChainWorkspace::new(
+            env.clone(),
+            test_dht.env(),
+            test_cache.env(),
+            keystore,
+            author.clone(),
+        )
+        .await
+        .unwrap();
         let mut ribosome = MockRibosomeT::new();
         let dna_def = DnaDefFixturator::new(Unpredictable).next().unwrap();
-        let dna_hash = DnaHash::with_data_sync(&dna_def);
         let dna_def_hashed = DnaDefHashed::from_content_sync(dna_def.clone());
         // Setup the ribosome mock
         ribosome
@@ -149,16 +168,14 @@ pub mod tests {
             .returning(move |_workspace, _invocation| Ok(InitResult::Pass));
         ribosome.expect_dna_def().return_const(dna_def_hashed);
 
-        let cell_id = CellId::new(dna_hash, fixt!(AgentPubKey));
-        let conductor_api = Arc::new(MockConductorHandleT::new());
-        let conductor_api = CellConductorApi::new(conductor_api, cell_id);
+        let conductor_handle = Arc::new(MockConductorHandleT::new());
         let args = InitializeZomesWorkflowArgs {
             ribosome,
             dna_def,
-            conductor_api,
+            conductor_handle,
         };
         let keystore = fixt!(MetaLairClient);
-        let network = fixt!(HolochainP2pCell);
+        let network = fixt!(HolochainP2pDna);
 
         initialize_zomes_workflow_inner(workspace.clone(), network, keystore, args)
             .await
@@ -179,13 +196,14 @@ pub mod tests {
             .await
             .unwrap();
         let mut conductor = SweetConductor::from_standard_config().await;
+        let keystore = conductor.keystore();
         let app = conductor.setup_app("app", &[dna]).await.unwrap();
         let (cell,) = app.into_tuple();
         let zome = cell.zome("create_entry");
 
-        assert_eq!(get_chain(&cell).await.len().unwrap(), 3);
+        assert_eq!(get_chain(&cell, keystore.clone()).await.len().unwrap(), 3);
         assert_eq!(
-            get_chain(&cell)
+            get_chain(&cell, keystore.clone())
                 .await
                 .query(Default::default())
                 .await
@@ -196,7 +214,7 @@ pub mod tests {
 
         let _: HeaderHash = conductor.call(&zome, "create_entry", ()).await;
 
-        let source_chain = get_chain(&cell).await;
+        let source_chain = get_chain(&cell, keystore.clone()).await;
         // - Ensure that the InitZomesComplete element got committed after the
         //   element committed during init()
         assert_matches!(
@@ -212,22 +230,23 @@ pub mod tests {
                 .await
                 .unwrap();
         let mut conductor = SweetConductor::from_standard_config().await;
+        let keystore = conductor.keystore();
         let app = conductor.setup_app("app", &[dna]).await.unwrap();
         let (cell,) = app.into_tuple();
         let zome = cell.zome("create_entry");
 
-        assert_eq!(get_chain(&cell).await.len().unwrap(), 3);
+        assert_eq!(get_chain(&cell, keystore.clone()).await.len().unwrap(), 3);
 
         // - Ensure that the chain does not advance due to init failing
         let r: Result<HeaderHash, _> = conductor.call_fallible(&zome, "create_entry", ()).await;
         assert!(r.is_err());
-        let source_chain = get_chain(&cell);
+        let source_chain = get_chain(&cell, keystore.clone());
         assert_eq!(source_chain.await.len().unwrap(), 3);
 
         // - Ensure idempotence of the above
         let r: Result<HeaderHash, _> = conductor.call_fallible(&zome, "create_entry", ()).await;
         assert!(r.is_err());
-        let source_chain = get_chain(&cell);
+        let source_chain = get_chain(&cell, keystore.clone());
         assert_eq!(source_chain.await.len().unwrap(), 3);
     }
 
@@ -255,22 +274,23 @@ pub mod tests {
         .unwrap();
 
         let mut conductor = SweetConductor::from_standard_config().await;
+        let keystore = conductor.keystore();
         let app = conductor.setup_app("app", &[dna]).await.unwrap();
         let (cell,) = app.into_tuple();
         let zome = cell.zome("no-init");
 
-        assert_eq!(get_chain(&cell).await.len().unwrap(), 3);
+        assert_eq!(get_chain(&cell, keystore.clone()).await.len().unwrap(), 3);
 
         // - Ensure that the chain does not advance due to init failing
         let r: Result<HeaderHash, _> = conductor.call_fallible(&zome, "create_entry", ()).await;
         assert!(r.is_err());
-        let source_chain = get_chain(&cell);
+        let source_chain = get_chain(&cell, keystore.clone());
         assert_eq!(source_chain.await.len().unwrap(), 3);
 
         // - Ensure idempotence of the above
         let r: Result<HeaderHash, _> = conductor.call_fallible(&zome, "create_entry", ()).await;
         assert!(r.is_err());
-        let source_chain = get_chain(&cell);
+        let source_chain = get_chain(&cell, keystore.clone());
         assert_eq!(source_chain.await.len().unwrap(), 3);
     }
 }
