@@ -2,7 +2,8 @@
 #![allow(deprecated)]
 
 use super::*;
-use crate::conductor::api::CellConductorApiT;
+use crate::conductor::handle::ConductorHandleT;
+use crate::conductor::space::Space;
 use crate::core::queue_consumer::TriggerSender;
 use crate::core::queue_consumer::WorkComplete;
 use crate::core::sys_validate::check_and_hold_store_element;
@@ -11,8 +12,8 @@ use crate::core::validation::*;
 use error::WorkflowResult;
 use holo_hash::DhtOpHash;
 use holochain_cascade::Cascade;
-use holochain_p2p::HolochainP2pCell;
-use holochain_p2p::HolochainP2pCellT;
+use holochain_p2p::HolochainP2pDna;
+use holochain_p2p::HolochainP2pDnaT;
 use holochain_sqlite::prelude::*;
 use holochain_state::host_fn_workspace::HostFnStores;
 use holochain_state::host_fn_workspace::HostFnWorkspace;
@@ -23,6 +24,7 @@ use holochain_zome_types::Entry;
 use holochain_zome_types::ValidationStatus;
 use rusqlite::Transaction;
 use std::convert::TryInto;
+use std::sync::Arc;
 use tracing::*;
 use types::Outcome;
 
@@ -41,23 +43,26 @@ mod tests;
 
 #[instrument(skip(
     workspace,
+    space,
     trigger_app_validation,
     sys_validation_trigger,
     network,
-    conductor_api
+    conductor_handle
 ))]
 pub async fn sys_validation_workflow(
-    workspace: SysValidationWorkspace,
+    workspace: Arc<SysValidationWorkspace>,
+    space: Arc<Space>,
     trigger_app_validation: TriggerSender,
     sys_validation_trigger: TriggerSender,
     // TODO: Update HolochainP2p to reflect changes to pass through network.
-    network: HolochainP2pCell,
-    conductor_api: impl CellConductorApiT,
+    network: HolochainP2pDna,
+    conductor_handle: &dyn ConductorHandleT,
 ) -> WorkflowResult<WorkComplete> {
     let complete = sys_validation_workflow_inner(
-        Arc::new(workspace),
+        workspace,
+        space,
         network,
-        conductor_api,
+        conductor_handle,
         sys_validation_trigger,
     )
     .await?;
@@ -72,13 +77,13 @@ pub async fn sys_validation_workflow(
 
 async fn sys_validation_workflow_inner(
     workspace: Arc<SysValidationWorkspace>,
-    network: HolochainP2pCell,
-    conductor_api: impl CellConductorApiT,
+    space: Arc<Space>,
+    network: HolochainP2pDna,
+    conductor_handle: &dyn ConductorHandleT,
     sys_validation_trigger: TriggerSender,
 ) -> WorkflowResult<WorkComplete> {
-    let env = workspace.vault.clone().into();
+    let env = workspace.dht_env.clone();
     let sorted_ops = validation_query::get_ops_to_sys_validate(&env).await?;
-    let conductor_api = Arc::new(conductor_api);
 
     // Process each op
     let iter = sorted_ops.into_iter().map(|so| {
@@ -86,18 +91,16 @@ async fn sys_validation_workflow_inner(
         // that we are meant to be holding but aren't.
         // If we are not holding them they will be added to our incoming ops.
         let incoming_dht_ops_sender =
-            IncomingDhtOpSender::new(workspace.vault.clone(), sys_validation_trigger.clone());
+            IncomingDhtOpSender::new(space.clone(), sys_validation_trigger.clone());
         let network = network.clone();
-        let conductor_api = conductor_api.clone();
         let workspace = workspace.clone();
         async move {
-            let conductor_api = conductor_api.clone();
             let (op, op_hash) = so.into_inner();
             let r = validate_op(
                 &op,
                 &(*workspace),
                 network,
-                &(*conductor_api),
+                conductor_handle,
                 Some(incoming_dht_ops_sender),
             )
             .await;
@@ -110,8 +113,8 @@ async fn sys_validation_workflow_inner(
         .ready_chunks(NUM_CONCURRENT_OPS);
 
     while let Some(chunk) = iter.next().await {
-        workspace
-            .vault
+        space
+            .dht_env
             .async_commit(move |mut txn| {
                 for outcome in chunk {
                     let (op_hash, outcome) = outcome?;
@@ -162,15 +165,15 @@ async fn sys_validation_workflow_inner(
 async fn validate_op(
     op: &DhtOp,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
-    conductor_api: &impl CellConductorApiT,
+    network: HolochainP2pDna,
+    conductor_handle: &dyn ConductorHandleT,
     incoming_dht_ops_sender: Option<IncomingDhtOpSender>,
 ) -> WorkflowResult<Outcome> {
     match validate_op_inner(
         op,
         workspace,
         network,
-        conductor_api,
+        conductor_handle,
         incoming_dht_ops_sender,
     )
     .await
@@ -184,7 +187,7 @@ async fn validate_op(
         // Handle the errors that result in pending or awaiting deps
         Err(SysValidationError::ValidationOutcome(e)) => {
             info!(
-                agent = %which_agent(conductor_api.cell_id().agent_pubkey()),
+                dna = %workspace.dna_hash(),
                 msg = "DhtOp did not pass system validation. (If rejected, a warning will follow.)",
                 ?op,
                 error = ?e,
@@ -193,7 +196,7 @@ async fn validate_op(
             let outcome = handle_failed(e);
             if let Outcome::Rejected = outcome {
                 warn!(
-                    agent = %which_agent(conductor_api.cell_id().agent_pubkey()),
+                    dna = %workspace.dna_hash(),
                     msg = "DhtOp was rejected during system validation.",
                     ?op,
                 )
@@ -241,8 +244,8 @@ fn handle_failed(error: ValidationOutcome) -> Outcome {
 async fn validate_op_inner(
     op: &DhtOp,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
-    conductor_api: &impl CellConductorApiT,
+    network: HolochainP2pDna,
+    conductor_handle: &dyn ConductorHandleT,
     incoming_dht_ops_sender: Option<IncomingDhtOpSender>,
 ) -> SysValidationResult<()> {
     match op {
@@ -271,7 +274,7 @@ async fn validate_op_inner(
                         .try_into()
                         .map_err(|_| ValidationOutcome::NotNewEntry(header.clone()))?,
                     entry.as_ref(),
-                    conductor_api,
+                    conductor_handle,
                     workspace,
                     network,
                 )
@@ -299,7 +302,7 @@ async fn validate_op_inner(
             store_entry(
                 (header).into(),
                 entry.as_ref(),
-                conductor_api,
+                conductor_handle,
                 workspace,
                 network.clone(),
             )
@@ -322,7 +325,7 @@ async fn validate_op_inner(
                 store_entry(
                     NewEntryHeaderRef::Update(header),
                     entry.as_ref(),
-                    conductor_api,
+                    conductor_handle,
                     workspace,
                     network.clone(),
                 )
@@ -338,7 +341,7 @@ async fn validate_op_inner(
                 store_entry(
                     NewEntryHeaderRef::Update(header),
                     entry.as_ref(),
-                    conductor_api,
+                    conductor_handle,
                     workspace,
                     network.clone(),
                 )
@@ -367,7 +370,7 @@ async fn validate_op_inner(
     }
 }
 
-#[instrument(skip(element, call_zome_workspace, network, conductor_api))]
+#[instrument(skip(element, call_zome_workspace, network, conductor_handle))]
 /// Direct system validation call that takes
 /// an Element instead of an op.
 /// Does not require holding dependencies.
@@ -376,31 +379,24 @@ async fn validate_op_inner(
 pub async fn sys_validate_element(
     element: &Element,
     call_zome_workspace: &HostFnWorkspace,
-    network: HolochainP2pCell,
-    conductor_api: &impl CellConductorApiT,
+    network: HolochainP2pDna,
+    conductor_handle: &dyn ConductorHandleT,
 ) -> SysValidationOutcome<()> {
     trace!(?element);
     // Create a SysValidationWorkspace with the scratches from the CallZomeWorkspace
     let workspace = SysValidationWorkspace::from(call_zome_workspace);
-    let result = match sys_validate_element_inner(element, &workspace, network, conductor_api).await
-    {
-        // Validation succeeded
-        Ok(_) => Ok(()),
-        // Validation failed so exit with that outcome
-        Err(SysValidationError::ValidationOutcome(validation_outcome)) => {
-            error!(msg = "Direct validation failed", ?element);
-            validation_outcome.into_outcome()
-        }
-        // An error occurred so return it
-        Err(e) => Err(OutcomeOrError::Err(e)),
-    };
-
-    // TODO: This is probably fine to remove because cache is now
-    // a separate db but confirm that.
-    // Set the call zome workspace to the updated
-    // cache from the sys validation workspace
-    // call_zome_workspace.meta_cache = workspace.meta_cache;
-    // call_zome_workspace.element_cache = workspace.element_cache;
+    let result =
+        match sys_validate_element_inner(element, &workspace, network, conductor_handle).await {
+            // Validation succeeded
+            Ok(_) => Ok(()),
+            // Validation failed so exit with that outcome
+            Err(SysValidationError::ValidationOutcome(validation_outcome)) => {
+                error!(msg = "Direct validation failed", ?element);
+                validation_outcome.into_outcome()
+            }
+            // An error occurred so return it
+            Err(e) => Err(OutcomeOrError::Err(e)),
+        };
 
     result
 }
@@ -408,8 +404,8 @@ pub async fn sys_validate_element(
 async fn sys_validate_element_inner(
     element: &Element,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
-    conductor_api: &impl CellConductorApiT,
+    network: HolochainP2pDna,
+    conductor_handle: &dyn ConductorHandleT,
 ) -> SysValidationResult<()> {
     let signature = element.signature();
     let header = element.header();
@@ -420,8 +416,8 @@ async fn sys_validate_element_inner(
         header: &Header,
         maybe_entry: Option<&Entry>,
         workspace: &SysValidationWorkspace,
-        network: HolochainP2pCell,
-        conductor_api: &impl CellConductorApiT,
+        network: HolochainP2pDna,
+        conductor_handle: &dyn ConductorHandleT,
     ) -> SysValidationResult<()> {
         let incoming_dht_ops_sender = None;
         store_element(header, workspace, network.clone()).await?;
@@ -433,7 +429,7 @@ async fn sys_validate_element_inner(
                     .try_into()
                     .map_err(|_| ValidationOutcome::NotNewEntry(header.clone()))?,
                 maybe_entry,
-                conductor_api,
+                conductor_handle,
                 workspace,
                 network.clone(),
             )
@@ -468,13 +464,13 @@ async fn sys_validate_element_inner(
                     maybe_entry,
                     workspace,
                     network.clone(),
-                    conductor_api,
+                    conductor_handle,
                 )
                 .await?;
             }
             Ok(())
         }
-        _ => validate(header, maybe_entry, workspace, network, conductor_api).await,
+        _ => validate(header, maybe_entry, workspace, network, conductor_handle).await,
     }
 }
 
@@ -489,7 +485,7 @@ pub async fn counterfeit_check(signature: &Signature, header: &Header) -> SysVal
 async fn register_agent_activity(
     header: &Header,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
+    network: HolochainP2pDna,
     incoming_dht_ops_sender: Option<IncomingDhtOpSender>,
 ) -> SysValidationResult<()> {
     // Get data ready to validate
@@ -515,7 +511,7 @@ async fn register_agent_activity(
 async fn store_element(
     header: &Header,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
+    network: HolochainP2pDna,
 ) -> SysValidationResult<()> {
     // Get data ready to validate
     let prev_header_hash = header.prev_header();
@@ -537,9 +533,9 @@ async fn store_element(
 async fn store_entry(
     header: NewEntryHeaderRef<'_>,
     entry: &Entry,
-    conductor_api: &impl CellConductorApiT,
+    conductor_handle: &dyn ConductorHandleT,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
+    network: HolochainP2pDna,
 ) -> SysValidationResult<()> {
     // Get data ready to validate
     let entry_type = header.entry_type();
@@ -548,7 +544,8 @@ async fn store_entry(
     // Checks
     check_entry_type(entry_type, entry)?;
     if let EntryType::App(app_entry_type) = entry_type {
-        let entry_def = check_app_entry_type(app_entry_type, conductor_api).await?;
+        let entry_def =
+            check_app_entry_type(workspace.dna_hash(), app_entry_type, conductor_handle).await?;
         check_not_private(&entry_def)?;
     }
 
@@ -579,7 +576,7 @@ async fn store_entry(
 async fn register_updated_content(
     entry_update: &Update,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
+    network: HolochainP2pDna,
     incoming_dht_ops_sender: Option<IncomingDhtOpSender>,
 ) -> SysValidationResult<()> {
     // Get data ready to validate
@@ -587,7 +584,6 @@ async fn register_updated_content(
 
     let dependency_check =
         |original_element: &Element| update_check(entry_update, original_element.header());
-
     check_and_hold_store_entry(
         original_header_address,
         workspace,
@@ -602,7 +598,7 @@ async fn register_updated_content(
 async fn register_updated_element(
     entry_update: &Update,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
+    network: HolochainP2pDna,
     incoming_dht_ops_sender: Option<IncomingDhtOpSender>,
 ) -> SysValidationResult<()> {
     // Get data ready to validate
@@ -625,7 +621,7 @@ async fn register_updated_element(
 async fn register_deleted_by(
     element_delete: &Delete,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
+    network: HolochainP2pDna,
     incoming_dht_ops_sender: Option<IncomingDhtOpSender>,
 ) -> SysValidationResult<()> {
     // Get data ready to validate
@@ -649,7 +645,7 @@ async fn register_deleted_by(
 async fn register_deleted_entry_header(
     element_delete: &Delete,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
+    network: HolochainP2pDna,
     incoming_dht_ops_sender: Option<IncomingDhtOpSender>,
 ) -> SysValidationResult<()> {
     // Get data ready to validate
@@ -673,7 +669,7 @@ async fn register_deleted_entry_header(
 async fn register_add_link(
     link_add: &CreateLink,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
+    network: HolochainP2pDna,
     incoming_dht_ops_sender: Option<IncomingDhtOpSender>,
 ) -> SysValidationResult<()> {
     // Get data ready to validate
@@ -703,7 +699,7 @@ async fn register_add_link(
 async fn register_delete_link(
     link_remove: &DeleteLink,
     workspace: &SysValidationWorkspace,
-    network: HolochainP2pCell,
+    network: HolochainP2pDna,
     incoming_dht_ops_sender: Option<IncomingDhtOpSender>,
 ) -> SysValidationResult<()> {
     // Get data ready to validate
@@ -732,21 +728,28 @@ fn update_check(entry_update: &Update, original_header: &Header) -> SysValidatio
 
 pub struct SysValidationWorkspace {
     scratch: Option<SyncScratch>,
-    vault: EnvWrite,
-    cache: EnvWrite,
+    authored_env: DbRead<DbKindAuthored>,
+    dht_env: DbRead<DbKindDht>,
+    cache: DbWrite<DbKindCache>,
 }
 
 impl SysValidationWorkspace {
-    pub fn new(vault: EnvWrite, cache: EnvWrite) -> Self {
+    pub fn new(
+        authored_env: DbRead<DbKindAuthored>,
+        dht_env: DbRead<DbKindDht>,
+        cache: DbWrite<DbKindCache>,
+    ) -> Self {
         Self {
-            vault,
+            authored_env,
+            dht_env,
             cache,
             scratch: None,
         }
     }
+
     pub async fn is_chain_empty(&self, author: AgentPubKey) -> SourceChainResult<bool> {
         let chain_not_empty = self
-            .vault
+            .dht_env
             .async_reader(move |txn| {
                 let mut stmt = txn.prepare(
                     "
@@ -787,7 +790,7 @@ impl SysValidationWorkspace {
         let seq = header.header_seq();
         let hash = HeaderHash::with_data_sync(header);
         let header_seq_is_not_empty = self
-            .vault
+            .dht_env
             .async_reader({
                 let hash = hash.clone();
                 move |txn| {
@@ -829,27 +832,31 @@ impl SysValidationWorkspace {
     }
     /// Create a cascade with local data only
     pub fn local_cascade(&self) -> Cascade {
-        let cascade = Cascade::empty()
-            .with_vault(self.vault.clone().into())
-            // TODO: Does the cache count as local?
-            .with_cache(self.cache.clone());
+        let cascade = Cascade::empty().with_dht(self.dht_env.clone());
         match &self.scratch {
-            Some(scratch) => cascade.with_scratch(scratch.clone()),
+            Some(scratch) => cascade
+                .with_authored(self.authored_env.clone())
+                .with_scratch(scratch.clone()),
             None => cascade,
         }
     }
-    pub fn full_cascade<Network: HolochainP2pCellT + Clone + 'static + Send>(
+    pub fn full_cascade<Network: HolochainP2pDnaT + Clone + 'static + Send>(
         &self,
         network: Network,
     ) -> Cascade<Network> {
         let cascade = Cascade::empty()
-            .with_vault(self.vault.clone().into())
+            .with_authored(self.authored_env.clone())
+            .with_dht(self.dht_env.clone())
             .with_network(network, self.cache.clone());
         match &self.scratch {
             Some(scratch) => cascade.with_scratch(scratch.clone()),
             None => cascade,
         }
     }
+
+    fn dna_hash(&self) -> &DnaHash {
+        self.dht_env.kind().dna_hash()
+    }
 }
 
 fn put_validation_limbo(
@@ -874,13 +881,15 @@ fn put_integration_limbo(
 impl From<&HostFnWorkspace> for SysValidationWorkspace {
     fn from(h: &HostFnWorkspace) -> Self {
         let HostFnStores {
-            vault,
             cache,
             scratch,
+            authored,
+            dht,
         } = h.stores();
         Self {
-            scratch: Some(scratch),
-            vault: vault.into(),
+            scratch,
+            authored_env: authored,
+            dht_env: dht,
             cache,
         }
     }
