@@ -1,13 +1,15 @@
 use super::SweetZome;
 use hdk::prelude::*;
 use holo_hash::DnaHash;
-use holochain_types::env::EnvWrite;
+use holochain_sqlite::db::{DbKindAuthored, DbKindDht};
+use holochain_types::env::DbWrite;
 /// A reference to a Cell created by a SweetConductor installation function.
 /// It has very concise methods for calling a zome on this cell
 #[derive(Clone, derive_more::Constructor)]
 pub struct SweetCell {
     pub(super) cell_id: CellId,
-    pub(super) cell_env: EnvWrite,
+    pub(super) cell_authored_env: DbWrite<DbKindAuthored>,
+    pub(super) cell_dht_env: DbWrite<DbKindDht>,
 }
 
 impl SweetCell {
@@ -16,9 +18,14 @@ impl SweetCell {
         &self.cell_id
     }
 
-    /// Get the environment for this cell
-    pub fn env(&self) -> &EnvWrite {
-        &self.cell_env
+    /// Get the authored environment for this cell
+    pub fn authored_env(&self) -> &DbWrite<DbKindAuthored> {
+        &self.cell_authored_env
+    }
+
+    /// Get the dht environment for this cell
+    pub fn dht_env(&self) -> &DbWrite<DbKindDht> {
+        &self.cell_dht_env
     }
 
     /// Accessor for AgentPubKey
